# Sample overview

This is a minimal Chrome extension that integrates with the Outreach Dialer.

## How to test the extension

1. `Load unpacked` this Chrome extension

2. Navigate to the Outreach app, then open the Javascript console

3. Attempt to make a call, and you should notice that the Javascript console shows `Content-Script: Dial attempt success`, which indicates that the round-trip integration succeeded.

# Integration overview

Your Chrome extension will need a `content-script.js`, which will listen for `outreach-external-dial-init`,
and then acknowledge the response by sending back `outreach-external-dial-ack`. This is done via
`window.addEventListener('message', ..)` and `window.postMessage('message', ..)`.

Example `content-script.js`:

```
window.addEventListener('message', (event) => {
    if (event.data.type !== 'outreach-external-dial-init') {
        return;
    }

    const { callId, phoneNumber } = event.data;

    // Let Outreach know that you've acknowledged the message.
    window.postMessage({
        type: 'outreach-external-dial-ack',

        // Include the same call ID so that Outreach can match your `-ack` messages.
        callId
    });

    // Your custom logic.
    await fetch(...);
});
```

## Event interface

`event.data` has the following Typescript definitions, depending on message type (`-init` or `-ack`):

```
// Sent by Outreach
interface DialInitMessageData {
  type: 'outreach-external-dial-init';

  // Indicates that this message came from Outreach, constant value.
  source: 'outreach';

  // A uuid for the call
  callId: string;

  phoneNumber: string;

  // Outreach will include the phone extension if the phone is configured with one.
  ext?: string;
}

// Sent by your `content-script.js`, to acknowledge the dial attempt.
interface DialAckMessageData {
  type: 'outreach-external-dial-ack';

  // This should have the same value as what was received from the `-init` message.
  callId: string;
}
```

# Production `manifest.json`

Make sure your `content_scripts` section includes the following:

```
  // Allows the content-script to run for Outreach domains.
  "matches": ["https://*.outreach.io/*"],

  // Allows the content-script to run in iframes; Outreach currently embeds the Outreach Dialer inside an iframe.
  "all_frames": true
```
